#[repr(i32)]pub enum BlizzardGame {
Show 22 variants
Unknown = 0,
WorldOfWarcraft = 1,
WorldOfWarcraftClassic = 2,
WorldOfWarcraftClassicEra = 3,
WarcraftIIBattleNetEdition = 4,
WarcraftIIRemastered = 5,
WarcraftIII = 6,
WarcraftIIIReforged = 7,
StarCraft = 8,
StarCraftRemastered = 9,
StarCraftII = 10,
Diablo = 11,
DiabloII = 12,
DiabloIIResurrected = 13,
DiabloIII = 14,
DiabloIV = 15,
DiabloImmortal = 16,
HeroesOfTheStorm = 17,
Overwatch2 = 18,
Hearthstone = 19,
BlizzardArcadeCollection = 20,
BattleNet = 21,
}Expand description
Known Blizzard game identifiers.
The Unknown value is used for games discovered via generic heuristics (e.g. the Windows Uninstall registry scan) that don’t match a known title. In that case, inspect the name field of the result for the display name.
Variants
Unknown = 0
WorldOfWarcraft = 1
WorldOfWarcraftClassic = 2
WorldOfWarcraftClassicEra = 3
WarcraftIIBattleNetEdition = 4
WarcraftIIRemastered = 5
WarcraftIII = 6
WarcraftIIIReforged = 7
StarCraft = 8
StarCraftRemastered = 9
StarCraftII = 10
Diablo = 11
DiabloII = 12
DiabloIIResurrected = 13
DiabloIII = 14
DiabloIV = 15
DiabloImmortal = 16
HeroesOfTheStorm = 17
Overwatch2 = 18
Hearthstone = 19
BlizzardArcadeCollection = 20
BattleNet = 21