AttachmentPoint

Struct AttachmentPoint 

pub struct AttachmentPoint { /* private fields */ }
ATT_ — Attachment point (v0–v1, 20 bytes)

Named bone location used by the engine to attach effects, weapons, or other models to specific skeleton bones.

Implementations

Source

impl AttachmentPoint

pub fn new() -> Self

Panics

Panics if the native allocation fails.

pub fn unknown(&self) -> u32

Unknown field

pub fn set_unknown(&mut self, value: u32)

pub fn name(&self) -> String

Attachment point name (Ref<CHAR>)

pub fn set_name(&mut self, value: &str)

pub fn bone_index(&self) -> u32

Index into BONE array

pub fn set_bone_index(&mut self, value: u32)