pub struct DisplacementMaterial { /* private fields */ }Expand description
DIS_ — Displacement material (v0–v4, 68 bytes)
Applies vertex displacement via a normal map and animated strength.
Implementations
Sourceimpl DisplacementMaterial
impl DisplacementMaterial
pub fn set_name(&mut self, value: &str)
pub fn set_unknown(&mut self, value: u32)
Sourcepub fn strength(&self) -> Ref<'_, AnimRefF32>
pub fn strength(&self) -> Ref<'_, AnimRefF32>
Animated displacement strength Borrows the field in place — no copy, no allocation.
pub fn strength_mut(&mut self) -> RefMut<'_, AnimRefF32>
pub fn set_priority(&mut self, value: u32)