HairMaterial

Struct HairMaterial 

pub struct HairMaterial { /* private fields */ }
HAI_ — Hair material (defunct, v0, 116 bytes)

Anisotropic hair rendering material with specular shift and AO. Always null in observed corpus data.

Implementations

Source

impl HairMaterial

pub fn new() -> Self

Panics

Panics if the native allocation fails.

pub fn name(&self) -> String

Material name (Ref<CHAR>)

pub fn set_name(&mut self, value: &str)

pub fn shift_primary(&self) -> f32

Primary specular shift

pub fn set_shift_primary(&mut self, value: f32)

pub fn shift_secondary(&self) -> f32

Secondary specular shift

pub fn set_shift_secondary(&mut self, value: f32)

pub fn color_diffuse(&self) -> Ref<'_, AnimRefM3ColorBGRA>

Animated diffuse tint Borrows the field in place — no copy, no allocation.

pub fn color_diffuse_mut(&mut self) -> RefMut<'_, AnimRefM3ColorBGRA>

pub fn color_spec(&self) -> Ref<'_, AnimRefM3ColorBGRA>

Animated specular tint Borrows the field in place — no copy, no allocation.

pub fn color_spec_mut(&mut self) -> RefMut<'_, AnimRefM3ColorBGRA>

pub fn spec_exponent_0(&self) -> f32

Primary specular exponent

pub fn set_spec_exponent_0(&mut self, value: f32)

pub fn spec_exponent_1(&self) -> f32

Secondary specular exponent

pub fn set_spec_exponent_1(&mut self, value: f32)