pub struct Camera { /* private fields */ }Expand description
Camera definition
Cameras define viewpoints that can be used for portrait renders or in-game cutscenes.
Implementations
Sourceimpl Camera
impl Camera
pub fn set_name(&mut self, value: &str)
pub fn set_position(&mut self, value: Vector3f)
Sourcepub fn field_of_view(&self) -> f32
pub fn field_of_view(&self) -> f32
Field of view angle in radians
pub fn set_field_of_view(&mut self, value: f32)
Sourcepub fn far_clipping_plane(&self) -> f32
pub fn far_clipping_plane(&self) -> f32
Far clipping distance
pub fn set_far_clipping_plane(&mut self, value: f32)
Sourcepub fn near_clipping_plane(&self) -> f32
pub fn near_clipping_plane(&self) -> f32
Near clipping distance
pub fn set_near_clipping_plane(&mut self, value: f32)
Sourcepub fn target_position(&self) -> Vector3f
pub fn target_position(&self) -> Vector3f
Look-at target position
pub fn set_target_position(&mut self, value: Vector3f)
Sourcepub fn position_tracks(&self) -> Ref<'_, TrackVector3f>
pub fn position_tracks(&self) -> Ref<'_, TrackVector3f>
Position animation Borrows the field in place — no copy, no allocation.
pub fn position_tracks_mut(&mut self) -> RefMut<'_, TrackVector3f>
Sourcepub fn target_rotation_tracks(&self) -> Ref<'_, TrackF32>
pub fn target_rotation_tracks(&self) -> Ref<'_, TrackF32>
Target rotation animation Borrows the field in place — no copy, no allocation.
pub fn target_rotation_tracks_mut(&mut self) -> RefMut<'_, TrackF32>
Sourcepub fn target_position_tracks(&self) -> Ref<'_, TrackVector3f>
pub fn target_position_tracks(&self) -> Ref<'_, TrackVector3f>
Target position animation Borrows the field in place — no copy, no allocation.
pub fn target_position_tracks_mut(&mut self) -> RefMut<'_, TrackVector3f>