CornEmitter

Struct CornEmitter 

pub struct CornEmitter { /* private fields */ }
PopcornFX particle emitter (Reforged)

Advanced particle system using PopcornFX technology in Warcraft III: Reforged. Color (RGB) and alpha are stored as separate fields with independent animation tracks.

Implementations

Source

impl CornEmitter

pub fn new() -> Self

Panics

Panics if the native allocation fails.

pub fn node(&self) -> Ref<'_, Node>

Base node data Borrows the field in place — no copy, no allocation.

pub fn node_mut(&mut self) -> RefMut<'_, Node>

pub fn life_span(&self) -> f32

Particle lifetime (default)

pub fn set_life_span(&mut self, value: f32)

pub fn emission_rate(&self) -> f32

Emission rate (default)

pub fn set_emission_rate(&mut self, value: f32)

pub fn speed(&self) -> f32

Particle speed (default)

pub fn set_speed(&mut self, value: f32)

pub fn color(&self) -> Vector3f

Particle color (RGB)

pub fn set_color(&mut self, value: Vector3f)

pub fn alpha(&self) -> f32

Particle alpha (default)

pub fn set_alpha(&mut self, value: f32)

pub fn replaceable_id(&self) -> u32

Replaceable texture ID

pub fn set_replaceable_id(&mut self, value: u32)

pub fn path(&self) -> String

Path to PopcornFX effect

pub fn set_path(&mut self, value: &str)

pub fn anim_visibility_guide(&self) -> String

Animation visibility guide

pub fn set_anim_visibility_guide(&mut self, value: &str)

pub fn life_span_tracks(&self) -> Ref<'_, TrackF32>

Lifespan animation Borrows the field in place — no copy, no allocation.

pub fn life_span_tracks_mut(&mut self) -> RefMut<'_, TrackF32>

pub fn emission_rate_tracks(&self) -> Ref<'_, TrackF32>

Emission rate animation Borrows the field in place — no copy, no allocation.

pub fn emission_rate_tracks_mut(&mut self) -> RefMut<'_, TrackF32>

pub fn speed_tracks(&self) -> Ref<'_, TrackF32>

Speed animation Borrows the field in place — no copy, no allocation.

pub fn speed_tracks_mut(&mut self) -> RefMut<'_, TrackF32>

pub fn color_tracks(&self) -> Ref<'_, TrackVector3f>

Color animation Borrows the field in place — no copy, no allocation.

pub fn color_tracks_mut(&mut self) -> RefMut<'_, TrackVector3f>

pub fn alpha_tracks(&self) -> Ref<'_, TrackF32>

Alpha animation Borrows the field in place — no copy, no allocation.

pub fn alpha_tracks_mut(&mut self) -> RefMut<'_, TrackF32>

pub fn visibility_tracks(&self) -> Ref<'_, TrackF32>

Visibility animation Borrows the field in place — no copy, no allocation.

pub fn visibility_tracks_mut(&mut self) -> RefMut<'_, TrackF32>