Light

Struct Light 

pub struct Light { /* private fields */ }
Light source

Lights can be attached to bones to move with animations. They affect how the model is rendered in the game engine.

Implementations

Source

impl Light

pub fn new() -> Self

Panics

Panics if the native allocation fails.

pub fn node(&self) -> Ref<'_, Node>

Base node data Borrows the field in place — no copy, no allocation.

pub fn node_mut(&mut self) -> RefMut<'_, Node>

pub fn type_(&self) -> LightType

Type of light

pub fn set_type_(&mut self, value: LightType)

pub fn attenuation_start(&self) -> f32

Distance where attenuation begins

pub fn set_attenuation_start(&mut self, value: f32)

pub fn attenuation_end(&self) -> f32

Distance where light reaches zero

pub fn set_attenuation_end(&mut self, value: f32)

pub fn color(&self) -> Vector3f

Light color (RGB)

pub fn set_color(&mut self, value: Vector3f)

pub fn intensity(&self) -> f32

Light intensity

pub fn set_intensity(&mut self, value: f32)

pub fn ambient_color(&self) -> Vector3f

Ambient light color

pub fn set_ambient_color(&mut self, value: Vector3f)

pub fn ambient_intensity(&self) -> f32

Ambient intensity

pub fn set_ambient_intensity(&mut self, value: f32)

pub fn shadow_intensity(&self) -> f32

Shadow darkness (Reforged)

pub fn set_shadow_intensity(&mut self, value: f32)

pub fn attenuation_start_tracks(&self) -> Ref<'_, TrackF32>

Attenuation start animation Borrows the field in place — no copy, no allocation.

pub fn attenuation_start_tracks_mut(&mut self) -> RefMut<'_, TrackF32>

pub fn attenuation_end_tracks(&self) -> Ref<'_, TrackF32>

Attenuation end animation Borrows the field in place — no copy, no allocation.

pub fn attenuation_end_tracks_mut(&mut self) -> RefMut<'_, TrackF32>

pub fn color_tracks(&self) -> Ref<'_, TrackVector3f>

Color animation Borrows the field in place — no copy, no allocation.

pub fn color_tracks_mut(&mut self) -> RefMut<'_, TrackVector3f>

pub fn intensity_tracks(&self) -> Ref<'_, TrackF32>

Intensity animation Borrows the field in place — no copy, no allocation.

pub fn intensity_tracks_mut(&mut self) -> RefMut<'_, TrackF32>

pub fn ambient_intensity_tracks(&self) -> Ref<'_, TrackF32>

Ambient intensity animation Borrows the field in place — no copy, no allocation.

pub fn ambient_intensity_tracks_mut(&mut self) -> RefMut<'_, TrackF32>

pub fn ambient_color_tracks(&self) -> Ref<'_, TrackVector3f>

Ambient color animation Borrows the field in place — no copy, no allocation.

pub fn ambient_color_tracks_mut(&mut self) -> RefMut<'_, TrackVector3f>

pub fn visibility_tracks(&self) -> Ref<'_, TrackF32>

Visibility animation Borrows the field in place — no copy, no allocation.

pub fn visibility_tracks_mut(&mut self) -> RefMut<'_, TrackF32>

pub fn shadow_intensity_tracks(&self) -> Ref<'_, TrackF32>

Shadow intensity animation (Reforged) Borrows the field in place — no copy, no allocation.

pub fn shadow_intensity_tracks_mut(&mut self) -> RefMut<'_, TrackF32>