Node

Struct Node 

pub struct Node { /* private fields */ }
Base node in the model hierarchy

Nodes form the skeleton and attachment system of the model. Each node can have a parent creating a transformation hierarchy. Nodes can be: - Bones (for skeletal animation) - Helpers (attachment points) - Lights - Particle emitters - And other special objects

Nodes contain transformation animation tracks (translation, rotation, scaling).

Implementations

Source

impl Node

pub fn new() -> Self

Panics

Panics if the native allocation fails.

pub fn name(&self) -> String

Node name (for debugging/reference)

pub fn set_name(&mut self, value: &str)

pub fn object_id(&self) -> u32

Unique ID for this node

pub fn set_object_id(&mut self, value: u32)

pub fn parent_id(&self) -> u32

Parent node ID or NO_PARENT

pub fn set_parent_id(&mut self, value: u32)

pub fn flags(&self) -> NodeFlag

Combination of NodeFlag values

pub fn set_flags(&mut self, value: NodeFlag)

pub fn type_(&self) -> NodeType

Type of this node

pub fn set_type_(&mut self, value: NodeType)

pub fn node_family_id(&self) -> u32

Used to link related nodes of the same type

pub fn set_node_family_id(&mut self, value: u32)

pub fn translation_tracks(&self) -> Ref<'_, TrackVector3f>

Position animation Borrows the field in place — no copy, no allocation.

pub fn translation_tracks_mut(&mut self) -> RefMut<'_, TrackVector3f>

pub fn rotation_tracks(&self) -> Ref<'_, TrackQuaternion>

Rotation animation (quaternion XYZW) Borrows the field in place — no copy, no allocation.

pub fn rotation_tracks_mut(&mut self) -> RefMut<'_, TrackQuaternion>

pub fn scaling_tracks(&self) -> Ref<'_, TrackVector3f>

Scale animation Borrows the field in place — no copy, no allocation.

pub fn scaling_tracks_mut(&mut self) -> RefMut<'_, TrackVector3f>