pub struct ParticleEmitter { /* private fields */ }Expand description
Particle emitter version 1 (uses external model)
Legacy particle emitter that spawns copies of an external model file. Used for effects like footprints, blood splatter, etc.
Implementations
Sourceimpl ParticleEmitter
impl ParticleEmitter
Sourcepub fn node(&self) -> Ref<'_, Node>
pub fn node(&self) -> Ref<'_, Node>
Base node data Borrows the field in place — no copy, no allocation.
pub fn node_mut(&mut self) -> RefMut<'_, Node>
Sourcepub fn emission_rate(&self) -> f32
pub fn emission_rate(&self) -> f32
Particles per second
pub fn set_emission_rate(&mut self, value: f32)
pub fn set_gravity(&mut self, value: f32)
pub fn set_longitude(&mut self, value: f32)
pub fn set_latitude(&mut self, value: f32)
Sourcepub fn spawn_model_file_name(&self) -> String
pub fn spawn_model_file_name(&self) -> String
Model to spawn as particles
pub fn set_spawn_model_file_name(&mut self, value: &str)
pub fn set_lifespan(&mut self, value: f32)
Sourcepub fn initial_velocity(&self) -> f32
pub fn initial_velocity(&self) -> f32
Initial particle speed
pub fn set_initial_velocity(&mut self, value: f32)
Sourcepub fn emission_rate_tracks(&self) -> Ref<'_, TrackF32>
pub fn emission_rate_tracks(&self) -> Ref<'_, TrackF32>
Emission rate animation Borrows the field in place — no copy, no allocation.
pub fn emission_rate_tracks_mut(&mut self) -> RefMut<'_, TrackF32>
Sourcepub fn gravity_tracks(&self) -> Ref<'_, TrackF32>
pub fn gravity_tracks(&self) -> Ref<'_, TrackF32>
Gravity animation Borrows the field in place — no copy, no allocation.
pub fn gravity_tracks_mut(&mut self) -> RefMut<'_, TrackF32>
Sourcepub fn longitude_tracks(&self) -> Ref<'_, TrackF32>
pub fn longitude_tracks(&self) -> Ref<'_, TrackF32>
Longitude animation Borrows the field in place — no copy, no allocation.
pub fn longitude_tracks_mut(&mut self) -> RefMut<'_, TrackF32>
Sourcepub fn latitude_tracks(&self) -> Ref<'_, TrackF32>
pub fn latitude_tracks(&self) -> Ref<'_, TrackF32>
Latitude animation Borrows the field in place — no copy, no allocation.
pub fn latitude_tracks_mut(&mut self) -> RefMut<'_, TrackF32>
Sourcepub fn lifespan_tracks(&self) -> Ref<'_, TrackF32>
pub fn lifespan_tracks(&self) -> Ref<'_, TrackF32>
Lifespan animation Borrows the field in place — no copy, no allocation.
pub fn lifespan_tracks_mut(&mut self) -> RefMut<'_, TrackF32>
Sourcepub fn speed_tracks(&self) -> Ref<'_, TrackF32>
pub fn speed_tracks(&self) -> Ref<'_, TrackF32>
Speed animation Borrows the field in place — no copy, no allocation.
pub fn speed_tracks_mut(&mut self) -> RefMut<'_, TrackF32>
Sourcepub fn visibility_tracks(&self) -> Ref<'_, TrackF32>
pub fn visibility_tracks(&self) -> Ref<'_, TrackF32>
Visibility animation Borrows the field in place — no copy, no allocation.