RibbonEmitter

Struct RibbonEmitter 

pub struct RibbonEmitter { /* private fields */ }
Ribbon/trail emitter

Creates ribbon trails that follow the emitter’s movement, like sword trails, missile contrails, etc.

Implementations

Source

impl RibbonEmitter

pub fn new() -> Self

Panics

Panics if the native allocation fails.

pub fn node(&self) -> Ref<'_, Node>

Base node data Borrows the field in place — no copy, no allocation.

pub fn node_mut(&mut self) -> RefMut<'_, Node>

pub fn height_above(&self) -> f32

Height above attachment point

pub fn set_height_above(&mut self, value: f32)

pub fn height_below(&self) -> f32

Height below attachment point

pub fn set_height_below(&mut self, value: f32)

pub fn alpha(&self) -> f32

Ribbon opacity

pub fn set_alpha(&mut self, value: f32)

pub fn color(&self) -> Vector3f

Ribbon color

pub fn set_color(&mut self, value: Vector3f)

pub fn lifespan(&self) -> f32

Ribbon segment lifetime

pub fn set_lifespan(&mut self, value: f32)

pub fn texture_slot(&self) -> u32

Texture slot in material

pub fn set_texture_slot(&mut self, value: u32)

pub fn emission_rate(&self) -> u32

Emission rate

pub fn set_emission_rate(&mut self, value: u32)

pub fn rows(&self) -> u32

Texture atlas rows

pub fn set_rows(&mut self, value: u32)

pub fn columns(&self) -> u32

Texture atlas columns

pub fn set_columns(&mut self, value: u32)

pub fn material_id(&self) -> u32

Material index

pub fn set_material_id(&mut self, value: u32)

pub fn gravity(&self) -> f32

Gravity effect

pub fn set_gravity(&mut self, value: f32)

pub fn height_above_tracks(&self) -> Ref<'_, TrackF32>

Height above animation Borrows the field in place — no copy, no allocation.

pub fn height_above_tracks_mut(&mut self) -> RefMut<'_, TrackF32>

pub fn height_below_tracks(&self) -> Ref<'_, TrackF32>

Height below animation Borrows the field in place — no copy, no allocation.

pub fn height_below_tracks_mut(&mut self) -> RefMut<'_, TrackF32>

pub fn alpha_tracks(&self) -> Ref<'_, TrackF32>

Alpha animation Borrows the field in place — no copy, no allocation.

pub fn alpha_tracks_mut(&mut self) -> RefMut<'_, TrackF32>

pub fn color_tracks(&self) -> Ref<'_, TrackVector3f>

Color animation Borrows the field in place — no copy, no allocation.

pub fn color_tracks_mut(&mut self) -> RefMut<'_, TrackVector3f>

pub fn texture_slot_tracks(&self) -> Ref<'_, TrackU32>

Texture slot animation Borrows the field in place — no copy, no allocation.

pub fn texture_slot_tracks_mut(&mut self) -> RefMut<'_, TrackU32>

pub fn visibility_tracks(&self) -> Ref<'_, TrackF32>

Visibility animation Borrows the field in place — no copy, no allocation.

pub fn visibility_tracks_mut(&mut self) -> RefMut<'_, TrackF32>