pub struct Sound { /* private fields */ }Expand description
Sound definition (deprecated, not used in shipped models)
Sounds define audio file paths and playback properties. While readers for this chunk exist in the internal game code, no known shipped model contains SNDS data.
Binary layout: 56 bytes per entry
Implementations
Sourceimpl Sound
impl Sound
Sourcepub fn sound_file(&self) -> String
pub fn sound_file(&self) -> String
Path to sound file (44 bytes, null-terminated)
pub fn set_sound_file(&mut self, value: &str)
Sourcepub fn maximum_distance(&self) -> f32
pub fn maximum_distance(&self) -> f32
Maximum audible distance
pub fn set_maximum_distance(&mut self, value: f32)
Sourcepub fn minimum_distance(&self) -> f32
pub fn minimum_distance(&self) -> f32
Minimum distance (full volume)
pub fn set_minimum_distance(&mut self, value: f32)
Sourcepub fn sound_channel(&self) -> u32
pub fn sound_channel(&self) -> u32
Sound channel identifier
pub fn set_sound_channel(&mut self, value: u32)