pub struct SoundEmitter { /* private fields */ }Expand description
Sound emitter attached to the model hierarchy (deprecated)
Sound emitters are positioned nodes that can emit sounds at specific animation frames via KSEK tracks. While readers exist in the internal game code, no known shipped model contains SNEM data.
Implementations
Sourceimpl SoundEmitter
impl SoundEmitter
Sourcepub fn node(&self) -> Ref<'_, Node>
pub fn node(&self) -> Ref<'_, Node>
Base node data with transform Borrows the field in place — no copy, no allocation.
pub fn node_mut(&mut self) -> RefMut<'_, Node>
Sourcepub fn sound_track(&self) -> Ref<'_, TrackU32>
pub fn sound_track(&self) -> Ref<'_, TrackU32>
KSEK - sound event track (u32 values) Borrows the field in place — no copy, no allocation.
pub fn sound_track_mut(&mut self) -> RefMut<'_, TrackU32>