pub struct TextureAnimation { /* private fields */ }Expand description
UV coordinate animation
Texture animations transform UV coordinates over time, creating effects like scrolling water, rotating symbols, etc.
Implementations
Sourceimpl TextureAnimation
impl TextureAnimation
Sourcepub fn translation_tracks(&self) -> Ref<'_, TrackVector3f>
pub fn translation_tracks(&self) -> Ref<'_, TrackVector3f>
UV translation animation Borrows the field in place — no copy, no allocation.
pub fn translation_tracks_mut(&mut self) -> RefMut<'_, TrackVector3f>
Sourcepub fn rotation_tracks(&self) -> Ref<'_, TrackQuaternion>
pub fn rotation_tracks(&self) -> Ref<'_, TrackQuaternion>
UV rotation animation (quaternion XYZW) Borrows the field in place — no copy, no allocation.
pub fn rotation_tracks_mut(&mut self) -> RefMut<'_, TrackQuaternion>
Sourcepub fn scaling_tracks(&self) -> Ref<'_, TrackVector3f>
pub fn scaling_tracks(&self) -> Ref<'_, TrackVector3f>
UV scaling animation Borrows the field in place — no copy, no allocation.
pub fn scaling_tracks_mut(&mut self) -> RefMut<'_, TrackVector3f>