Skip to main contentModule textures
Source - BlpParser
- Parser for BLP texture files
- BlpWriter
- Writer for BLP texture files
- BmpParser
- Reads a BMP file or byte buffer and decodes it into a Texture.
- BmpWriter
- Encodes a Texture into BMP format.
- D2rTextureParser
- Reads a Diablo II: Resurrected
.texture file and decodes it into a Texture. - D2rTextureWriter
- Encodes a Texture into the Diablo II: Resurrected
.texture format. - DdsParser
- Reads a DDS file or byte buffer and decodes it into a Texture.
- DdsWriter
- Encodes a Texture into DDS format.
- GifSaveOptions
- Per-write options for GIF encoding.
- GifWriter
- Encodes a sequence of Texture frames into GIF89a format.
- JpegParser
- Reads a JPEG file or byte buffer and decodes it into a Texture.
- JpegWriter
- Encodes a Texture into JPEG format.
- MipLevel
- Describes a single mip level within a Texture’s data buffer.
- PngApngFrame
- One frame of an animated PNG (APNG), with its display duration.
- PngApngFrameInfo
- Per-frame metadata for an animated PNG (APNG).
- PngApngSaveOptions
- Options controlling animated PNG (APNG) encoding.
- PngParser
- Reads a PNG file or byte buffer and decodes it into a Texture.
- PngWriter
- Encodes a Texture into PNG format.
- TexParser
- Reads a TEX file or byte buffer and decodes it into a Texture.
- Texture
- Format-agnostic GPU texture container
- TextureList
- An owned list of
Texture produced by the library. - TgaParser
- Reads a TGA file or byte buffer and decodes it into a Texture.
- TgaWriter
- Encodes a Texture into TGA format.
- TiffParser
- Reads a TIFF file or byte buffer and decodes it into a Texture.
- TiffWriter
- Encodes a Texture into TIFF format.
- Channel
- Individual colour / data channel within a pixel.
- PixelFormat
- GPU pixel / block-compression format.
- TextureKind
- Semantic role of a texture in a material.
- TextureType
- Dimensionality / topology of a texture resource.