pub struct JpegParser { /* private fields */ }Expand description
Reads a JPEG file or byte buffer and decodes it into a Texture.
Implementations
Sourceimpl JpegParser
impl JpegParser
Sourcepub fn has_issues(&self) -> bool
pub fn has_issues(&self) -> bool
@return true if the last parse produced any issues.