TexParser

Struct TexParser 

pub struct TexParser { /* private fields */ }
Reads a TEX file or byte buffer and decodes it into a Texture.

Implementations

Source

impl TexParser

pub fn new() -> Self

Panics

Panics if the native allocation fails.

pub fn parse(&mut self, file_path: &str) -> Option<Texture>

Parse a TEX file from disk.

pub fn parse_buffer(&mut self, buffer: &[u8]) -> Option<Texture>

Parse a TEX byte buffer.

pub fn parse_tex_file_path_payload_file_path( &mut self, tex_file_path: &str, payload_file_path: &str, ) -> Option<Texture>

Parse a D4 TEX file from two file paths (metadata .tex + pixel payload).

pub fn parse_tex_data_payload_data( &mut self, tex_data: &[u8], payload_data: &[u8], ) -> Option<Texture>

Parse a D4 TEX file from two byte buffers (metadata + pixel payload).

pub fn parse_tex_file_path_hi_res_payload_file_path_low_res_payload_file_path( &mut self, tex_file_path: &str, hi_res_payload_file_path: &str, low_res_payload_file_path: &str, ) -> Option<Texture>

Parse a D4 TEX with hi-res + low-res payloads from file paths.

pub fn has_issues(&self) -> bool

@return true if the last parse produced any issues.

pub fn issues(&self) -> Vec<String>

@return accumulated issues from the last parse call.