pub struct AttachmentPoint { /* private fields */ }Expand description
ATT_ — Attachment point (v0–v1, 20 bytes)
Named bone location used by the engine to attach effects, weapons, or other models to specific skeleton bones.
Implementations
Sourceimpl AttachmentPoint
impl AttachmentPoint
pub fn set_unknown(&mut self, value: u32)
pub fn set_name(&mut self, value: &str)
Sourcepub fn bone_index(&self) -> u32
pub fn bone_index(&self) -> u32
Index into BONE array
pub fn set_bone_index(&mut self, value: u32)