pub struct Force { /* private fields */ }Expand description
FOR_ — Force field (v0–v2, 104 bytes)
Applies radial, wind, or explosion forces to particles and ribbons within an influence volume shape (sphere, cylinder, box, hemisphere).
Implementations
Sourceimpl Force
impl Force
Sourcepub fn force_type(&self) -> ForceType
pub fn force_type(&self) -> ForceType
Force influence type (radial/wind/explosion)
pub fn set_force_type(&mut self, value: ForceType)
Sourcepub fn force_shape(&self) -> ForceShape
pub fn force_shape(&self) -> ForceShape
Influence volume shape
pub fn set_force_shape(&mut self, value: ForceShape)
pub fn set_unknown(&mut self, value: u32)
Sourcepub fn bone_index(&self) -> u32
pub fn bone_index(&self) -> u32
Index into BONE array
pub fn set_bone_index(&mut self, value: u32)
pub fn set_flags(&mut self, value: ForceFlag)
Sourcepub fn local_channels(&self) -> u32
pub fn local_channels(&self) -> u32
Local channel bitmask
pub fn set_local_channels(&mut self, value: u32)
Sourcepub fn strength(&self) -> Ref<'_, AnimRefF32>
pub fn strength(&self) -> Ref<'_, AnimRefF32>
Animated force strength Borrows the field in place — no copy, no allocation.
pub fn strength_mut(&mut self) -> RefMut<'_, AnimRefF32>
Sourcepub fn width(&self) -> Ref<'_, AnimRefF32>
pub fn width(&self) -> Ref<'_, AnimRefF32>
Animated influence width Borrows the field in place — no copy, no allocation.
pub fn width_mut(&mut self) -> RefMut<'_, AnimRefF32>
Sourcepub fn height(&self) -> Ref<'_, AnimRefF32>
pub fn height(&self) -> Ref<'_, AnimRefF32>
Animated influence height Borrows the field in place — no copy, no allocation.
pub fn height_mut(&mut self) -> RefMut<'_, AnimRefF32>
Sourcepub fn length(&self) -> Ref<'_, AnimRefF32>
pub fn length(&self) -> Ref<'_, AnimRefF32>
Animated influence length Borrows the field in place — no copy, no allocation.
pub fn length_mut(&mut self) -> RefMut<'_, AnimRefF32>