pub struct HairMaterial { /* private fields */ }Expand description
HAI_ — Hair material (defunct, v0, 116 bytes)
Anisotropic hair rendering material with specular shift and AO. Always null in observed corpus data.
Implementations
Sourceimpl HairMaterial
impl HairMaterial
pub fn set_name(&mut self, value: &str)
Sourcepub fn shift_primary(&self) -> f32
pub fn shift_primary(&self) -> f32
Primary specular shift
pub fn set_shift_primary(&mut self, value: f32)
Sourcepub fn shift_secondary(&self) -> f32
pub fn shift_secondary(&self) -> f32
Secondary specular shift
pub fn set_shift_secondary(&mut self, value: f32)
Sourcepub fn color_diffuse(&self) -> Ref<'_, AnimRefM3ColorBGRA>
pub fn color_diffuse(&self) -> Ref<'_, AnimRefM3ColorBGRA>
Animated diffuse tint Borrows the field in place — no copy, no allocation.
pub fn color_diffuse_mut(&mut self) -> RefMut<'_, AnimRefM3ColorBGRA>
Sourcepub fn color_spec(&self) -> Ref<'_, AnimRefM3ColorBGRA>
pub fn color_spec(&self) -> Ref<'_, AnimRefM3ColorBGRA>
Animated specular tint Borrows the field in place — no copy, no allocation.
pub fn color_spec_mut(&mut self) -> RefMut<'_, AnimRefM3ColorBGRA>
Sourcepub fn spec_exponent_0(&self) -> f32
pub fn spec_exponent_0(&self) -> f32
Primary specular exponent
pub fn set_spec_exponent_0(&mut self, value: f32)
Sourcepub fn spec_exponent_1(&self) -> f32
pub fn spec_exponent_1(&self) -> f32
Secondary specular exponent
pub fn set_spec_exponent_1(&mut self, value: f32)