pub struct Light { /* private fields */ }Expand description
LITE — Light source (v0–v7, 212 bytes)
Omni, spot, or directional light with animated diffuse/specular colors, intensity, decay, attenuation start/end, and spot-light hot-spot/falloff.
Implementations
Sourceimpl Light
impl Light
Sourcepub fn light_type(&self) -> LightType
pub fn light_type(&self) -> LightType
Light type (omni/spot/directional)
pub fn set_light_type(&mut self, value: LightType)
Sourcepub fn bone_index(&self) -> u16
pub fn bone_index(&self) -> u16
Index into BONE array
pub fn set_bone_index(&mut self, value: u16)
pub fn set_flags(&mut self, value: LightFlag)
pub fn set_lod_cut(&mut self, value: u32)
Sourcepub fn shadow_lod_cut(&self) -> u32
pub fn shadow_lod_cut(&self) -> u32
Shadow LOD cut-off level
pub fn set_shadow_lod_cut(&mut self, value: u32)
Sourcepub fn diffuse_color(&self) -> Ref<'_, AnimRefVector3f>
pub fn diffuse_color(&self) -> Ref<'_, AnimRefVector3f>
Animated diffuse color (RGB) Borrows the field in place — no copy, no allocation.
pub fn diffuse_color_mut(&mut self) -> RefMut<'_, AnimRefVector3f>
Sourcepub fn intensity_multiplier(&self) -> Ref<'_, AnimRefF32>
pub fn intensity_multiplier(&self) -> Ref<'_, AnimRefF32>
Animated intensity multiplier Borrows the field in place — no copy, no allocation.
pub fn intensity_multiplier_mut(&mut self) -> RefMut<'_, AnimRefF32>
Sourcepub fn specular_color(&self) -> Ref<'_, AnimRefVector3f>
pub fn specular_color(&self) -> Ref<'_, AnimRefVector3f>
Animated specular color (RGB) Borrows the field in place — no copy, no allocation.
pub fn specular_color_mut(&mut self) -> RefMut<'_, AnimRefVector3f>
Sourcepub fn specular_multiplier(&self) -> Ref<'_, AnimRefF32>
pub fn specular_multiplier(&self) -> Ref<'_, AnimRefF32>
Animated specular multiplier Borrows the field in place — no copy, no allocation.
pub fn specular_multiplier_mut(&mut self) -> RefMut<'_, AnimRefF32>
Sourcepub fn decay(&self) -> Ref<'_, AnimRefF32>
pub fn decay(&self) -> Ref<'_, AnimRefF32>
Animated distance decay exponent Borrows the field in place — no copy, no allocation.
pub fn decay_mut(&mut self) -> RefMut<'_, AnimRefF32>
Sourcepub fn attenuation_end(&self) -> f32
pub fn attenuation_end(&self) -> f32
Attenuation end distance
pub fn set_attenuation_end(&mut self, value: f32)
Sourcepub fn attenuation_start(&self) -> Ref<'_, AnimRefF32>
pub fn attenuation_start(&self) -> Ref<'_, AnimRefF32>
Animated attenuation start distance Borrows the field in place — no copy, no allocation.
pub fn attenuation_start_mut(&mut self) -> RefMut<'_, AnimRefF32>
Sourcepub fn hot_spot(&self) -> Ref<'_, AnimRefF32>
pub fn hot_spot(&self) -> Ref<'_, AnimRefF32>
Animated spot inner cone angle Borrows the field in place — no copy, no allocation.
pub fn hot_spot_mut(&mut self) -> RefMut<'_, AnimRefF32>
Sourcepub fn falloff(&self) -> Ref<'_, AnimRefF32>
pub fn falloff(&self) -> Ref<'_, AnimRefF32>
Animated spot outer cone falloff Borrows the field in place — no copy, no allocation.