pub struct Projector { /* private fields */ }Expand description
PROJ — Projector / decal (v0–v5, 388 bytes)
Projects a material onto scene geometry with animated offset, orientation, field of view, aspect ratio, clipping planes, alpha lifecycle, and attenuation distance.
Implementations
Sourceimpl Projector
impl Projector
Sourcepub fn projection_type(&self) -> ProjectionType
pub fn projection_type(&self) -> ProjectionType
Projection type (ortho/perspective)
pub fn set_projection_type(&mut self, value: ProjectionType)
pub fn set_bone(&mut self, value: u32)
Sourcepub fn material_reference_index(&self) -> u32
pub fn material_reference_index(&self) -> u32
Index into MATM material map
pub fn set_material_reference_index(&mut self, value: u32)
Sourcepub fn offset(&self) -> Ref<'_, AnimRefVector3f>
pub fn offset(&self) -> Ref<'_, AnimRefVector3f>
Animated position offset Borrows the field in place — no copy, no allocation.
pub fn offset_mut(&mut self) -> RefMut<'_, AnimRefVector3f>
Sourcepub fn pitch(&self) -> Ref<'_, AnimRefF32>
pub fn pitch(&self) -> Ref<'_, AnimRefF32>
Animated pitch angle Borrows the field in place — no copy, no allocation.
pub fn pitch_mut(&mut self) -> RefMut<'_, AnimRefF32>
Sourcepub fn yaw(&self) -> Ref<'_, AnimRefF32>
pub fn yaw(&self) -> Ref<'_, AnimRefF32>
Animated yaw angle Borrows the field in place — no copy, no allocation.
pub fn yaw_mut(&mut self) -> RefMut<'_, AnimRefF32>
Sourcepub fn roll(&self) -> Ref<'_, AnimRefF32>
pub fn roll(&self) -> Ref<'_, AnimRefF32>
Animated roll angle Borrows the field in place — no copy, no allocation.
pub fn roll_mut(&mut self) -> RefMut<'_, AnimRefF32>
Sourcepub fn field_of_view(&self) -> Ref<'_, AnimRefF32>
pub fn field_of_view(&self) -> Ref<'_, AnimRefF32>
Animated field of view Borrows the field in place — no copy, no allocation.
pub fn field_of_view_mut(&mut self) -> RefMut<'_, AnimRefF32>
Sourcepub fn aspect_ratio(&self) -> Ref<'_, AnimRefF32>
pub fn aspect_ratio(&self) -> Ref<'_, AnimRefF32>
Animated aspect ratio Borrows the field in place — no copy, no allocation.
pub fn aspect_ratio_mut(&mut self) -> RefMut<'_, AnimRefF32>
Sourcepub fn near(&self) -> Ref<'_, AnimRefF32>
pub fn near(&self) -> Ref<'_, AnimRefF32>
Animated near clip plane Borrows the field in place — no copy, no allocation.
pub fn near_mut(&mut self) -> RefMut<'_, AnimRefF32>
Sourcepub fn far(&self) -> Ref<'_, AnimRefF32>
pub fn far(&self) -> Ref<'_, AnimRefF32>
Animated far clip plane Borrows the field in place — no copy, no allocation.
pub fn far_mut(&mut self) -> RefMut<'_, AnimRefF32>
Sourcepub fn box_offset_z_bottom(&self) -> Ref<'_, AnimRefF32>
pub fn box_offset_z_bottom(&self) -> Ref<'_, AnimRefF32>
Animated box Z bottom offset Borrows the field in place — no copy, no allocation.
pub fn box_offset_z_bottom_mut(&mut self) -> RefMut<'_, AnimRefF32>
Sourcepub fn box_offset_z_top(&self) -> Ref<'_, AnimRefF32>
pub fn box_offset_z_top(&self) -> Ref<'_, AnimRefF32>
Animated box Z top offset Borrows the field in place — no copy, no allocation.
pub fn box_offset_z_top_mut(&mut self) -> RefMut<'_, AnimRefF32>
Sourcepub fn box_offset_x_left(&self) -> Ref<'_, AnimRefF32>
pub fn box_offset_x_left(&self) -> Ref<'_, AnimRefF32>
Animated box X left offset Borrows the field in place — no copy, no allocation.
pub fn box_offset_x_left_mut(&mut self) -> RefMut<'_, AnimRefF32>
Sourcepub fn box_offset_x_right(&self) -> Ref<'_, AnimRefF32>
pub fn box_offset_x_right(&self) -> Ref<'_, AnimRefF32>
Animated box X right offset Borrows the field in place — no copy, no allocation.
pub fn box_offset_x_right_mut(&mut self) -> RefMut<'_, AnimRefF32>
Sourcepub fn box_offset_y_front(&self) -> Ref<'_, AnimRefF32>
pub fn box_offset_y_front(&self) -> Ref<'_, AnimRefF32>
Animated box Y front offset Borrows the field in place — no copy, no allocation.
pub fn box_offset_y_front_mut(&mut self) -> RefMut<'_, AnimRefF32>
Sourcepub fn box_offset_y_back(&self) -> Ref<'_, AnimRefF32>
pub fn box_offset_y_back(&self) -> Ref<'_, AnimRefF32>
Animated box Y back offset Borrows the field in place — no copy, no allocation.
pub fn box_offset_y_back_mut(&mut self) -> RefMut<'_, AnimRefF32>
pub fn set_falloff(&mut self, value: f32)
Sourcepub fn alpha_init(&self) -> f32
pub fn alpha_init(&self) -> f32
Alpha at creation
pub fn set_alpha_init(&mut self, value: f32)
pub fn set_alpha_mid(&mut self, value: f32)
pub fn set_alpha_end(&mut self, value: f32)
Sourcepub fn lifetime_attack(&self) -> f32
pub fn lifetime_attack(&self) -> f32
Attack phase duration
pub fn set_lifetime_attack(&mut self, value: f32)
Sourcepub fn lifetime_attack_to(&self) -> f32
pub fn lifetime_attack_to(&self) -> f32
Attack target time
pub fn set_lifetime_attack_to(&mut self, value: f32)
Sourcepub fn lifetime_hold(&self) -> f32
pub fn lifetime_hold(&self) -> f32
Hold phase duration
pub fn set_lifetime_hold(&mut self, value: f32)
Sourcepub fn lifetime_hold_to(&self) -> f32
pub fn lifetime_hold_to(&self) -> f32
Hold target time
pub fn set_lifetime_hold_to(&mut self, value: f32)
Sourcepub fn lifetime_decay(&self) -> f32
pub fn lifetime_decay(&self) -> f32
Decay phase duration
pub fn set_lifetime_decay(&mut self, value: f32)
Sourcepub fn lifetime_decay_to(&self) -> f32
pub fn lifetime_decay_to(&self) -> f32
Decay target time
pub fn set_lifetime_decay_to(&mut self, value: f32)
Sourcepub fn attenuation_distance(&self) -> f32
pub fn attenuation_distance(&self) -> f32
Distance-based attenuation
pub fn set_attenuation_distance(&mut self, value: f32)
Sourcepub fn active(&self) -> Ref<'_, AnimRefU32>
pub fn active(&self) -> Ref<'_, AnimRefU32>
Animated active state Borrows the field in place — no copy, no allocation.
pub fn active_mut(&mut self) -> RefMut<'_, AnimRefU32>
pub fn set_layer(&mut self, value: u32)
Sourcepub fn lod_reduce(&self) -> u32
pub fn lod_reduce(&self) -> u32
LOD reduction level
pub fn set_lod_reduce(&mut self, value: u32)
pub fn set_lod_cut(&mut self, value: u32)
Sourcepub fn flags(&self) -> ProjectorFlag
pub fn flags(&self) -> ProjectorFlag
Projector flags