pub struct SubFlare { /* private fields */ }Expand description
LFSB — Sub-flare element (v0–v2, 56 bytes)
A single flare element within a LensFlare material, with position, size, scale, fade, color, and offset parameters.
Implementations
Sourceimpl SubFlare
impl SubFlare
pub fn set_index(&mut self, value: u32)
pub fn set_position(&mut self, value: f32)
pub fn set_size_xy(&mut self, value: Vector2f)
pub fn set_scale_xy(&mut self, value: Vector2f)
pub fn set_fade_in(&mut self, value: Vector2f)
pub fn set_fade_out(&mut self, value: Vector2f)
Sourcepub fn color_alpha(&self) -> Ref<'_, ColorBGRA>
pub fn color_alpha(&self) -> Ref<'_, ColorBGRA>
Flare color and alpha Borrows the field in place — no copy, no allocation.
pub fn color_alpha_mut(&mut self) -> RefMut<'_, ColorBGRA>
Sourcepub fn face_center(&self) -> u32
pub fn face_center(&self) -> u32
Whether to face the flare center
pub fn set_face_center(&mut self, value: u32)
pub fn set_offset(&mut self, value: Vector2f)