pub struct VolumeNoiseMaterial { /* private fields */ }Expand description
VON_ — Volume noise material (v0, 268 bytes)
Volumetric noise-based rendering material with animated density, falloff, scroll rate, position, scale, and rotation. Used for gas/smoke/cloud effects.
Implementations
Sourceimpl VolumeNoiseMaterial
impl VolumeNoiseMaterial
pub fn set_name(&mut self, value: &str)
Sourcepub fn falloff_type(&self) -> VolumeFalloffType
pub fn falloff_type(&self) -> VolumeFalloffType
Density falloff type
pub fn set_falloff_type(&mut self, value: VolumeFalloffType)
Sourcepub fn draw_transparency(&self) -> VolumeNoiseCameraMode
pub fn draw_transparency(&self) -> VolumeNoiseCameraMode
Camera position mode (inside/outside)
pub fn set_draw_transparency(&mut self, value: VolumeNoiseCameraMode)
Sourcepub fn density(&self) -> Ref<'_, AnimRefF32>
pub fn density(&self) -> Ref<'_, AnimRefF32>
Animated density Borrows the field in place — no copy, no allocation.
pub fn density_mut(&mut self) -> RefMut<'_, AnimRefF32>
Sourcepub fn near_plane(&self) -> Ref<'_, AnimRefF32>
pub fn near_plane(&self) -> Ref<'_, AnimRefF32>
Animated near-plane clip Borrows the field in place — no copy, no allocation.
pub fn near_plane_mut(&mut self) -> RefMut<'_, AnimRefF32>
Sourcepub fn falloff(&self) -> Ref<'_, AnimRefF32>
pub fn falloff(&self) -> Ref<'_, AnimRefF32>
Animated falloff distance Borrows the field in place — no copy, no allocation.
pub fn falloff_mut(&mut self) -> RefMut<'_, AnimRefF32>
Sourcepub fn scroll_rate(&self) -> Ref<'_, AnimRefVector3f>
pub fn scroll_rate(&self) -> Ref<'_, AnimRefVector3f>
Animated noise scroll rate Borrows the field in place — no copy, no allocation.
pub fn scroll_rate_mut(&mut self) -> RefMut<'_, AnimRefVector3f>
Sourcepub fn position(&self) -> Ref<'_, AnimRefVector3f>
pub fn position(&self) -> Ref<'_, AnimRefVector3f>
Animated volume position Borrows the field in place — no copy, no allocation.
pub fn position_mut(&mut self) -> RefMut<'_, AnimRefVector3f>
Sourcepub fn scale(&self) -> Ref<'_, AnimRefVector3f>
pub fn scale(&self) -> Ref<'_, AnimRefVector3f>
Animated volume scale Borrows the field in place — no copy, no allocation.
pub fn scale_mut(&mut self) -> RefMut<'_, AnimRefVector3f>
Sourcepub fn rotation(&self) -> Ref<'_, AnimRefVector3f>
pub fn rotation(&self) -> Ref<'_, AnimRefVector3f>
Animated volume rotation Borrows the field in place — no copy, no allocation.
pub fn rotation_mut(&mut self) -> RefMut<'_, AnimRefVector3f>
Sourcepub fn alpha_threshold(&self) -> u32
pub fn alpha_threshold(&self) -> u32
Alpha test threshold
pub fn set_alpha_threshold(&mut self, value: u32)
Sourcepub fn flags(&self) -> VolumeNoiseMaterialFlag
pub fn flags(&self) -> VolumeNoiseMaterialFlag
Volume noise material flags