Warp

Struct Warp 

pub struct Warp { /* private fields */ }
WRP_ — Warp field (v0–v1, 132 bytes)

Warps particle/ribbon trajectories with animated radius, height, and angular/axial/radial strength components.

Implementations

Source

impl Warp

pub fn new() -> Self

Panics

Panics if the native allocation fails.

pub fn warp_type(&self) -> u32

Warp type

pub fn set_warp_type(&mut self, value: u32)

pub fn bone_index(&self) -> u32

Index into BONE array

pub fn set_bone_index(&mut self, value: u32)

pub fn unknown(&self) -> u32

Unknown field

pub fn set_unknown(&mut self, value: u32)

pub fn radius(&self) -> Ref<'_, AnimRefF32>

Animated warp radius Borrows the field in place — no copy, no allocation.

pub fn radius_mut(&mut self) -> RefMut<'_, AnimRefF32>

pub fn height(&self) -> Ref<'_, AnimRefF32>

Animated warp height Borrows the field in place — no copy, no allocation.

pub fn height_mut(&mut self) -> RefMut<'_, AnimRefF32>

pub fn strength(&self) -> Ref<'_, AnimRefF32>

Animated warp strength Borrows the field in place — no copy, no allocation.

pub fn strength_mut(&mut self) -> RefMut<'_, AnimRefF32>

pub fn angular(&self) -> Ref<'_, AnimRefF32>

Animated angular component Borrows the field in place — no copy, no allocation.

pub fn angular_mut(&mut self) -> RefMut<'_, AnimRefF32>

pub fn axial(&self) -> Ref<'_, AnimRefF32>

Animated axial component Borrows the field in place — no copy, no allocation.

pub fn axial_mut(&mut self) -> RefMut<'_, AnimRefF32>

pub fn radial(&self) -> Ref<'_, AnimRefF32>

Animated radial component Borrows the field in place — no copy, no allocation.

pub fn radial_mut(&mut self) -> RefMut<'_, AnimRefF32>