pub struct Node { /* private fields */ }Expand description
Base node in the model hierarchy
Nodes form the skeleton and attachment system of the model. Each node can have a parent creating a transformation hierarchy. Nodes can be: - Bones (for skeletal animation) - Helpers (attachment points) - Lights - Particle emitters - And other special objects
Nodes contain transformation animation tracks (translation, rotation, scaling).
Implementations
Sourceimpl Node
impl Node
pub fn set_name(&mut self, value: &str)
pub fn set_object_id(&mut self, value: u32)
pub fn set_parent_id(&mut self, value: u32)
pub fn set_flags(&mut self, value: NodeFlag)
pub fn set_type_(&mut self, value: NodeType)
Sourcepub fn node_family_id(&self) -> u32
pub fn node_family_id(&self) -> u32
Used to link related nodes of the same type
pub fn set_node_family_id(&mut self, value: u32)
Sourcepub fn translation_tracks(&self) -> Ref<'_, TrackVector3f>
pub fn translation_tracks(&self) -> Ref<'_, TrackVector3f>
Position animation Borrows the field in place — no copy, no allocation.
pub fn translation_tracks_mut(&mut self) -> RefMut<'_, TrackVector3f>
Sourcepub fn rotation_tracks(&self) -> Ref<'_, TrackQuaternion>
pub fn rotation_tracks(&self) -> Ref<'_, TrackQuaternion>
Rotation animation (quaternion XYZW) Borrows the field in place — no copy, no allocation.
pub fn rotation_tracks_mut(&mut self) -> RefMut<'_, TrackQuaternion>
Sourcepub fn scaling_tracks(&self) -> Ref<'_, TrackVector3f>
pub fn scaling_tracks(&self) -> Ref<'_, TrackVector3f>
Scale animation Borrows the field in place — no copy, no allocation.
pub fn scaling_tracks_mut(&mut self) -> RefMut<'_, TrackVector3f>