ParticleEmitter

Struct ParticleEmitter 

pub struct ParticleEmitter { /* private fields */ }
Particle emitter version 1 (uses external model)

Legacy particle emitter that spawns copies of an external model file. Used for effects like footprints, blood splatter, etc.

Implementations

Source

impl ParticleEmitter

pub fn new() -> Self

Panics

Panics if the native allocation fails.

pub fn node(&self) -> Ref<'_, Node>

Base node data Borrows the field in place — no copy, no allocation.

pub fn node_mut(&mut self) -> RefMut<'_, Node>

pub fn emission_rate(&self) -> f32

Particles per second

pub fn set_emission_rate(&mut self, value: f32)

pub fn gravity(&self) -> f32

Gravity force

pub fn set_gravity(&mut self, value: f32)

pub fn longitude(&self) -> f32

Emission longitude angle

pub fn set_longitude(&mut self, value: f32)

pub fn latitude(&self) -> f32

Emission latitude angle

pub fn set_latitude(&mut self, value: f32)

pub fn spawn_model_file_name(&self) -> String

Model to spawn as particles

pub fn set_spawn_model_file_name(&mut self, value: &str)

pub fn lifespan(&self) -> f32

Particle lifetime in seconds

pub fn set_lifespan(&mut self, value: f32)

pub fn initial_velocity(&self) -> f32

Initial particle speed

pub fn set_initial_velocity(&mut self, value: f32)

pub fn emission_rate_tracks(&self) -> Ref<'_, TrackF32>

Emission rate animation Borrows the field in place — no copy, no allocation.

pub fn emission_rate_tracks_mut(&mut self) -> RefMut<'_, TrackF32>

pub fn gravity_tracks(&self) -> Ref<'_, TrackF32>

Gravity animation Borrows the field in place — no copy, no allocation.

pub fn gravity_tracks_mut(&mut self) -> RefMut<'_, TrackF32>

pub fn longitude_tracks(&self) -> Ref<'_, TrackF32>

Longitude animation Borrows the field in place — no copy, no allocation.

pub fn longitude_tracks_mut(&mut self) -> RefMut<'_, TrackF32>

pub fn latitude_tracks(&self) -> Ref<'_, TrackF32>

Latitude animation Borrows the field in place — no copy, no allocation.

pub fn latitude_tracks_mut(&mut self) -> RefMut<'_, TrackF32>

pub fn lifespan_tracks(&self) -> Ref<'_, TrackF32>

Lifespan animation Borrows the field in place — no copy, no allocation.

pub fn lifespan_tracks_mut(&mut self) -> RefMut<'_, TrackF32>

pub fn speed_tracks(&self) -> Ref<'_, TrackF32>

Speed animation Borrows the field in place — no copy, no allocation.

pub fn speed_tracks_mut(&mut self) -> RefMut<'_, TrackF32>

pub fn visibility_tracks(&self) -> Ref<'_, TrackF32>

Visibility animation Borrows the field in place — no copy, no allocation.

pub fn visibility_tracks_mut(&mut self) -> RefMut<'_, TrackF32>