ParticleEmitter2

Struct ParticleEmitter2 

pub struct ParticleEmitter2 { /* private fields */ }
Particle emitter version 2 (sprite-based)

More advanced particle system that uses sprite textures. Supports various particle shapes, blending modes, and animation over the particle lifetime. Used for fire, smoke, magic effects, etc.

Implementations

Source

impl ParticleEmitter2

pub fn new() -> Self

Panics

Panics if the native allocation fails.

pub fn node(&self) -> Ref<'_, Node>

Base node data Borrows the field in place — no copy, no allocation.

pub fn node_mut(&mut self) -> RefMut<'_, Node>

pub fn speed(&self) -> f32

Particle speed

pub fn set_speed(&mut self, value: f32)

pub fn variation(&self) -> f32

Speed variation (randomness)

pub fn set_variation(&mut self, value: f32)

pub fn latitude(&self) -> f32

Emission cone latitude

pub fn set_latitude(&mut self, value: f32)

pub fn gravity(&self) -> f32

Gravity acceleration

pub fn set_gravity(&mut self, value: f32)

pub fn lifespan(&self) -> f32

Particle lifetime in seconds

pub fn set_lifespan(&mut self, value: f32)

pub fn emission_rate(&self) -> f32

Particles per second

pub fn set_emission_rate(&mut self, value: f32)

pub fn length(&self) -> f32

Particle length (for tail effect)

pub fn set_length(&mut self, value: f32)

pub fn width(&self) -> f32

Particle width

pub fn set_width(&mut self, value: f32)

pub fn filter_mode(&self) -> u32

Blending mode

pub fn set_filter_mode(&mut self, value: u32)

pub fn rows(&self) -> u32

Texture atlas rows

pub fn set_rows(&mut self, value: u32)

pub fn columns(&self) -> u32

Texture atlas columns

pub fn set_columns(&mut self, value: u32)

pub fn head_or_tail(&self) -> u32

Head/tail flags

pub fn set_head_or_tail(&mut self, value: u32)

pub fn tail_length(&self) -> f32

Tail particle length

pub fn set_tail_length(&mut self, value: f32)

pub fn time(&self) -> f32

Middle time for segment animation

pub fn set_time(&mut self, value: f32)

pub fn segment_color_len() -> usize

Color at start/middle/end

pub fn segment_color(&self, index: usize) -> Vector3f

pub fn segment_alpha_len() -> usize

Alpha at start/middle/end

pub fn segment_alpha(&self, index: usize) -> u8

pub fn set_segment_alpha(&mut self, index: usize, value: u8)

pub fn segment_scaling_len() -> usize

Scale at start/middle/end

pub fn segment_scaling(&self, index: usize) -> f32

pub fn set_segment_scaling(&mut self, index: usize, value: f32)

pub fn head_interval_len() -> usize

Head lifetime intervals

pub fn head_interval(&self, index: usize) -> u32

pub fn set_head_interval(&mut self, index: usize, value: u32)

pub fn head_decay_interval_len() -> usize

Head decay intervals

pub fn head_decay_interval(&self, index: usize) -> u32

pub fn set_head_decay_interval(&mut self, index: usize, value: u32)

pub fn tail_interval_len() -> usize

Tail lifetime intervals

pub fn tail_interval(&self, index: usize) -> u32

pub fn set_tail_interval(&mut self, index: usize, value: u32)

pub fn tail_decay_interval_len() -> usize

Tail decay intervals

pub fn tail_decay_interval(&self, index: usize) -> u32

pub fn set_tail_decay_interval(&mut self, index: usize, value: u32)

pub fn texture_id(&self) -> u32

Texture index

pub fn set_texture_id(&mut self, value: u32)

pub fn squirt(&self) -> u32

Squirt flag (burst mode)

pub fn set_squirt(&mut self, value: u32)

pub fn priority_plane(&self) -> i32

Rendering priority; signed

pub fn set_priority_plane(&mut self, value: i32)

pub fn replaceable_id(&self) -> u32

Replaceable texture ID

pub fn set_replaceable_id(&mut self, value: u32)

pub fn speed_tracks(&self) -> Ref<'_, TrackF32>

Speed animation Borrows the field in place — no copy, no allocation.

pub fn speed_tracks_mut(&mut self) -> RefMut<'_, TrackF32>

pub fn variation_tracks(&self) -> Ref<'_, TrackF32>

Variation animation Borrows the field in place — no copy, no allocation.

pub fn variation_tracks_mut(&mut self) -> RefMut<'_, TrackF32>

pub fn latitude_tracks(&self) -> Ref<'_, TrackF32>

Latitude animation Borrows the field in place — no copy, no allocation.

pub fn latitude_tracks_mut(&mut self) -> RefMut<'_, TrackF32>

pub fn gravity_tracks(&self) -> Ref<'_, TrackF32>

Gravity animation Borrows the field in place — no copy, no allocation.

pub fn gravity_tracks_mut(&mut self) -> RefMut<'_, TrackF32>

pub fn emission_rate_tracks(&self) -> Ref<'_, TrackF32>

Emission rate animation Borrows the field in place — no copy, no allocation.

pub fn emission_rate_tracks_mut(&mut self) -> RefMut<'_, TrackF32>

pub fn length_tracks(&self) -> Ref<'_, TrackF32>

Length animation Borrows the field in place — no copy, no allocation.

pub fn length_tracks_mut(&mut self) -> RefMut<'_, TrackF32>

pub fn width_tracks(&self) -> Ref<'_, TrackF32>

Width animation Borrows the field in place — no copy, no allocation.

pub fn width_tracks_mut(&mut self) -> RefMut<'_, TrackF32>

pub fn visibility_tracks(&self) -> Ref<'_, TrackF32>

Visibility animation Borrows the field in place — no copy, no allocation.

pub fn visibility_tracks_mut(&mut self) -> RefMut<'_, TrackF32>