pub struct TrackQuaternion { /* private fields */ }Expand description
Generic animation track with keyframe data
Tracks store animation data as a series of keyframes. The interpolation type determines how values between keyframes are calculated.
@tparam T The value type (f32, Vector3f, Vector4f, u32, etc.)
Implementations
Sourceimpl TrackQuaternion
impl TrackQuaternion
pub fn set_is_used(&mut self, value: bool)
Sourcepub fn interpolation_type(&self) -> InterpolationType
pub fn interpolation_type(&self) -> InterpolationType
Interpolation type
pub fn set_interpolation_type(&mut self, value: InterpolationType)
Sourcepub fn global_sequence_id(&self) -> u32
pub fn global_sequence_id(&self) -> u32
Global sequence ID if applicable
pub fn set_global_sequence_id(&mut self, value: u32)
pub fn set_key_count(&mut self, value: usize)
Sourcepub fn timestamps(&self) -> &[u32]
pub fn timestamps(&self) -> &[u32]
Keyframe timestamps (in frames)
Zero-copy view of the underlying std::vector.
Sourcepub fn timestamps_mut(&mut self) -> &mut [u32]
pub fn timestamps_mut(&mut self) -> &mut [u32]
Zero-copy mutable view. Resize first — the borrow forbids it after.
pub fn set_timestamps(&mut self, values: &[u32])
pub fn resize_timestamps(&mut self, count: usize)
Sourcepub fn keys(&self) -> &[Quaternion]
pub fn keys(&self) -> &[Quaternion]
Raw keyframe data
Zero-copy view of the underlying std::vector.
Sourcepub fn keys_mut(&mut self) -> &mut [Quaternion]
pub fn keys_mut(&mut self) -> &mut [Quaternion]
Zero-copy mutable view. Resize first — the borrow forbids it after.
pub fn set_keys(&mut self, values: &[Quaternion])
pub fn resize_keys(&mut self, count: usize)